Enum lifx_core::ApplicationRequest [−][src]
#[repr(u8)]pub enum ApplicationRequest { NoApply, Apply, ApplyOnly, }
Controls how/when multizone devices apply color changes
See also Message::SetColorZones.
Variants
NoApplyDon't apply the requested changes until a message with Apply or ApplyOnly is sent
ApplyApply the changes immediately and apply any pending changes
ApplyOnlyIgnore the requested changes in this message and only apply pending changes