Struct lifx_core::HSBK[][src]

pub struct HSBK {
    pub hue: u16,
    pub saturation: u16,
    pub brightness: u16,
    pub kelvin: u16,
}

Bulb color (Hue-Saturation-Brightness-Kelvin)

Notes:

Colors are represented as Hue-Saturation-Brightness-Kelvin, or HSBK

When a light is displaying whites, saturation will be zero, hue will be ignored, and only brightness and kelvin will matter.

Normal values for "kelvin" are from 2500 (warm/yellow) to 9000 (cool/blue)

When a light is displaying colors, kelvin is ignored.

To display "pure" colors, set saturation to full (65535).

Fields

Methods

impl HSBK
[src]