RawMessage

Struct RawMessage 

pub struct RawMessage {
    pub frame: Frame,
    pub frame_addr: FrameAddress,
    pub protocol_header: ProtocolHeader,
    pub payload: Vec<u8>,
}
The raw message structure

Contains a low-level protocol info. This is what is sent and received via UDP packets.

To parse the payload, use Message::from_raw.

Fields

frame: Frameframe_addr: FrameAddressprotocol_header: ProtocolHeaderpayload: Vec<u8>

Implementations

Source

impl RawMessage

pub fn build(options: &BuildOptions, typ: Message) -> Result<RawMessage, Error>

Build a RawMessage (which is suitable for sending on the network) from a given Message type.

If BuildOptions::target is None, then the message is addressed to all devices. Else it should be a bulb UID (MAC address)

pub fn packed_size(&self) -> usize

The total size (in bytes) of the packed version of this message.

pub fn validate(&self)

Validates that this object was constructed correctly. Panics if not.

pub fn pack(&self) -> Result<Vec<u8>, Error>

Packs this RawMessage into some bytes that can be send over the network.

The length of the returned data will be RawMessage::packed_size in size.

pub fn unpack(v: &[u8]) -> Result<RawMessage, Error>

Given some bytes (generally read from a network socket), unpack the data into a RawMessage structure.