Enum lifx_core::Error [−][src]
Various message encoding/decoding errors
Variants
UnknownMessageType(u16)This error means we were unable to parse a raw message because its type is unknown.
LIFX devices are known to send messages that are not officially documented, so this error type does not necessarily represent a bug.
ProtocolError(String)This error means one of the message fields contains an invalid or unsupported value.
The inner string is a description of the error.
Io(Error)