Struct lifx_core::BuildOptions [−][src]
pub struct BuildOptions {
pub target: Option<u64>,
pub ack_required: bool,
pub res_required: bool,
pub sequence: u8,
pub source: u32,
}Options used to contruct a RawMessage.
See also RawMessage::build.
Fields
target: Option<u64>
If not None, this is the ID of the device you want to address.
To look up the ID of a device, extract it from the FrameAddress::target field when a device sends a Message::StateService message.
ack_required: bool
Acknowledgement message required.
Causes the light to send an Message::Acknowledgement message.
res_required: bool
Response message required.
Some message types are sent by clients to get data from a light. These should always have
res_required set to true.
sequence: u8
A wrap around sequence number. Optional (can be zero).
By providing a unique sequence value, the response message will also contain the same
sequence number, allowing a client to distinguish between different messages sent with the
same source identifier.
source: u32
A unique client identifier. Optional (can be zero).
If the source is non-zero, then the LIFX device with send a unicast message to the IP address/port of the client that sent the originating message. If zero, then the LIFX device may send a broadcast message that can be received by all clients on the same sub-net.