Struct lifx_core::HSBK [−][src]
Bulb color (Hue-Saturation-Brightness-Kelvin)
Notes:
Colors are represented as Hue-Saturation-Brightness-Kelvin, or HSBK
When a light is displaying whites, saturation will be zero, hue will be ignored, and only brightness and kelvin will matter.
Normal values for "kelvin" are from 2500 (warm/yellow) to 9000 (cool/blue)
When a light is displaying colors, kelvin is ignored.
To display "pure" colors, set saturation to full (65535).
Fields
hue: u16
saturation: u16
brightness: u16
kelvin: u16
Methods
impl HSBK[src]
impl HSBKTrait Implementations
impl Debug for HSBK[src]
impl Debug for HSBKfn fmt(&self, f: &mut Formatter) -> Result[src]
fn fmt(&self, f: &mut Formatter) -> ResultFormats the value using the given formatter. Read more
impl Copy for HSBK[src]
impl Copy for HSBKimpl Clone for HSBK[src]
impl Clone for HSBKfn clone(&self) -> HSBK[src]
fn clone(&self) -> HSBKReturns a copy of the value. Read more
fn clone_from(&mut self, source: &Self)1.0.0[src]
fn clone_from(&mut self, source: &Self)1.0.0
[src]Performs copy-assignment from source. Read more
impl PartialEq for HSBK[src]
impl PartialEq for HSBK