Struct lifx_core::RawMessage[][src]

pub struct RawMessage {
    pub frame: Frame,
    pub frame_addr: FrameAddress,
    pub protocol_header: ProtocolHeader,
    pub payload: Vec<u8>,
}

The raw message structure

Contains a low-level protocol info. This is what is sent and received via UDP packets.

To parse the payload, use Message::from_raw.

Fields

Methods

impl RawMessage
[src]

Build a RawMessage (which is suitable for sending on the network) from a given Message type.

If BuildOptions::target is None, then the message is addressed to all devices. Else it should be a bulb UID (MAC address)

The total size (in bytes) of the packed version of this message.

Validates that this object was constructed correctly. Panics if not.

Packs this RawMessage into some bytes that can be send over the network.

The length of the returned data will be RawMessage::packed_size in size.

Given some bytes (generally read from a network socket), unpack the data into a RawMessage structure.